@@ -59,6 +59,12 @@ int main()
 {
   bool rtv = true;
 
+#ifdef WIN32
+  WSADATA wsadata;
+  WORD vers = MAKEWORD(2, 2);
+  WSAStartup(vers, &wsadata);
+#endif
+
   try_url ("file:///allo", rtv,
 		  "file",
 		  "", "",
@@ -131,6 +137,39 @@ int main()
 		   "", "",
 		   "", 0,
 		   "80");
+
+  /* Handle the case where there is nothing other than the scheme */
+  try_url ("http://", rtv,
+		   "http",
+		   "", "",
+		   "", 80,
+		   "");
+
+  /* Check windows style URL */
+  try_url ("file:///E:/dir/file.pac", rtv,
+		  "file",
+		  "", "",
+		  "", 0,
+#ifdef WIN32
+          "E:\\dir\\file.pac");
+#else
+          "/E:/dir/file.pac");
+#endif
+
+  /* UNC windows URL */
+  try_url ("file://server/dir/file.pac", rtv,
+		  "file",
+		  "", "",
+		  "server", 0,
+#ifdef WIN32
+          "\\\\server\\dir\\file.pac");
+#else
+          "/dir/file.pac");
+#endif
+
+#ifdef WIN32
+  WSACleanup();
+#endif
   
   return !rtv;
 }
